==> chembl_webservices-2.2.0.tar.gz: chembl_webservices-2.2.0/chembl_webservices/resources/target_components.py <==
__author__ = 'mnowotka'

from tastypie import fields
from tastypie.resources import ALL, ALL_WITH_RELATIONS
from chembl_webservices.core.resource import ChemblModelResource
from chembl_webservices.core.serialization import ChEMBLApiSerializer
from chembl_webservices.core.meta import ChemblResourceMeta
try:
    from chembl_compatibility.models import TargetComponents
except ImportError:
    from chembl_core_model.models import TargetComponents
try:
    from chembl_compatibility.models import ComponentSequences
except ImportError:
    from chembl_core_model.models import ComponentSequences
try:
    from chembl_compatibility.models import ProteinClassification
except ImportError:
    from chembl_core_model.models import ProteinClassification

#-----------------------------------------------------------------------------------------------------------------------

class ProteinClassificationResource(ChemblModelResource):

    protein_classification_id = fields.IntegerField('protein_class_id')

    class Meta(ChemblResourceMeta):
        fields = ['']
        queryset = ProteinClassification.objects.all()
        resource_name = 'protein_classification'
        collection_name = 'protein_classifications'
        serializer = ChEMBLApiSerializer(resource_name, {collection_name : resource_name})

#-----------------------------------------------------------------------------------------------------------------------

class TargetComponentsResource(ChemblModelResource):

    protein_classifications = fields.ToManyField(
        'chembl_webservices.resources.target_components.ProteinClassificationResource',
        'proteinclassification_set', full=True, null=True, blank=True)
    target_component_synonyms = fields.ToManyField('chembl_webservices.resources.target.TargetComponentSynonyms',
        'componentsynonyms_set', full=True, null=True, blank=True)

    class Meta(ChemblResourceMeta):
        queryset = ComponentSequences.objects.all()
        excludes = ['db_source', 'db_version', 'sequence_md5sum']
        resource_name = 'target_component'
        collection_name = 'target_components'
        serializer = ChEMBLApiSerializer(resource_name, {collection_name : resource_name,
                                                         'target_component_synonyms': 'target_component_synonym'})
        prefetch_related = ['proteinclassification_set', 'componentsynonyms_set']

        fields = (
            'accession',
            'sequence',
            'component_id',
            'component_type',
            'description',
            'organism',
            'tax_id',
        )

        filtering = {
            'accession' : ALL,
            'component_id' : ALL,
            'component_type' : ALL,
            'description' : ALL,
            'organism' : ALL,
            'tax_id': ALL,
        }

        ordering = filtering.keys()

#-----------------------------------------------------------------------------------------------------------------------

==> chembl_webservices-2.3.7.tar.gz: chembl_webservices-2.3.7/chembl_webservices/resources/target_components.py <==
__author__ = 'mnowotka'

from tastypie import fields
from tastypie.resources import ALL, ALL_WITH_RELATIONS
from chembl_webservices.core.utils import FLAG_FILTERS
from chembl_webservices.core.resource import ChemblModelResource
from chembl_webservices.core.serialization import ChEMBLApiSerializer
from chembl_webservices.core.meta import ChemblResourceMeta
try:
    from chembl_compatibility.models import TargetComponents
except ImportError:
    from chembl_core_model.models import TargetComponents
try:
    from chembl_compatibility.models import ComponentSequences
except ImportError:
    from chembl_core_model.models import ComponentSequences
try:
    from chembl_compatibility.models import ProteinClassification
except ImportError:
    from chembl_core_model.models import ProteinClassification
try:
    from chembl_compatibility.models import TargetDictionary
except ImportError:
    from chembl_core_model.models import TargetDictionary
try:
    from chembl_compatibility.models import GoClassification
except ImportError:
    from chembl_core_model.models import GoClassification


from chembl_webservices.core.fields import monkeypatch_tastypie_field
monkeypatch_tastypie_field()

available_fields = [f.name for f in TargetDictionary._meta.fields]

#-----------------------------------------------------------------------------------------------------------------------

class ProteinClassificationResource(ChemblModelResource):

    protein_classification_id = fields.IntegerField('protein_class_id')

    class Meta(ChemblResourceMeta):
        queryset = ProteinClassification.objects.all()
        resource_name = 'protein_classification'
        collection_name = 'protein_classifications'
        serializer = ChEMBLApiSerializer(resource_name, {collection_name : resource_name})

        fields = ('protein_classification_id',)

        filtering = {
            'protein_classification_id' : FLAG_FILTERS,
        }

#-----------------------------------------------------------------------------------------------------------------------

class TargetDictionaryResource(ChemblModelResource):

    target_chembl_id = fields.CharField('chembl__chembl_id')

    class Meta(ChemblResourceMeta):
        queryset = TargetDictionary.objects.all() if 'downgraded' not in available_fields else \
            TargetDictionary.objects.filter(downgraded=False)

        fields = (
            'target_chembl_id',
        )

        filtering = {
            'target_chembl_id' : ALL,
        }

#-----------------------------------------------------------------------------------------------------------------------

class GoSlimResource(ChemblModelResource):

    class Meta(ChemblResourceMeta):
        queryset = GoClassification.objects.all()

        fields = (
            'go_id',
        )

        filtering = {
            'go_id' : ALL,
        }

#-----------------------------------------------------------------------------------------------------------------------

class TargetComponentsResource(ChemblModelResource):

    protein_classifications = fields.ToManyField(
        'chembl_webservices.resources.target_components.ProteinClassificationResource',
        'proteinclassification_set', full=True, null=True, blank=True)
    target_component_synonyms = fields.ToManyField('chembl_webservices.resources.target.TargetComponentSynonyms',
        'componentsynonyms_set', full=True, null=True, blank=True)
    targets = fields.ToManyField(
        'chembl_webservices.resources.target_components.TargetDictionaryResource',
        'targetdictionary_set', full=True, null=True, blank=True)
    go_slims = fields.ToManyField(
        'chembl_webservices.resources.target_components.GoSlimResource',
        'componentgo_set', full=True, null=True, blank=True)


    class Meta(ChemblResourceMeta):
        queryset = ComponentSequences.objects.defer('sequence')
        excludes = ['db_source', 'db_version', 'sequence_md5sum']
        resource_name = 'target_component'
        collection_name = 'target_components'
        serializer = ChEMBLApiSerializer(resource_name, {collection_name : resource_name,
                                                         'target_component_synonyms': 'target_component_synonym',
                                                         'protein_classifications': 'protein_classification',
                                                         'targets':'target'})
        prefetch_related = ['proteinclassification_set', 'componentsynonyms_set', 'targetdictionary_set',
                            'componentgo_set', 'targetdictionary_set__chembl']

        fields = (
            'accession',
            'sequence',
            'component_id',
            'component_type',
            'description',
            'organism',
            'tax_id',
            'targets'
        )

        filtering = {
            'accession' : ALL,
            'component_id' : ALL,
            'component_type' : ALL,
            'description' : ALL,
            'organism' : ALL,
            'tax_id': ALL,
            'protein_classifications': ALL_WITH_RELATIONS,
        }

        ordering = filtering.keys()

#-----------------------------------------------------------------------------------------------------------------------
